@@ -4,10 +4,15 @@ import uvicorn
 from starlette.applications import Starlette
 
 
-SERVER_PORT = "8080"
+_DEFAULTS = {"port": "8080"}
 
 
 def run(app: Starlette, **kwargs):
     # The log_config argument takes a logging.dictConfig that is applied to the
     # uvicorn logging.
-    uvicorn.run(app, port=int(os.environ.get("SERVER_PORT", SERVER_PORT)), **kwargs)
+
+    overrides = {}
+    port = os.environ.get("SERVER_PORT")
+    if port is not None:
+        overrides["port"] = port
+    uvicorn.run(app, **{**_DEFAULTS, **overrides, **kwargs})
